==> flex-checks-2.3-sources.jar: org/sonar/flex/checks/NotEnoughCaseForSwitchCheck.java <==
/*
 * SonarQube Flex Plugin
 * Copyright (C) 2010-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.flex.checks;

import com.sonar.sslr.api.AstNode;
import org.sonar.check.Priority;
import org.sonar.check.Rule;
import org.sonar.flex.FlexGrammar;
import org.sonar.flex.checks.utils.Tags;
import org.sonar.squidbridge.annotations.ActivatedByDefault;
import org.sonar.squidbridge.annotations.SqaleConstantRemediation;
import org.sonar.squidbridge.checks.SquidCheck;
import org.sonar.sslr.parser.LexerlessGrammar;

@Rule(
  key = "S1301",
  name = "\"switch\" statements should have at least 3 \"case\" clauses",
  priority = Priority.MINOR,
  tags = Tags.MISRA)
@ActivatedByDefault
@SqaleConstantRemediation("5min")
public class NotEnoughCaseForSwitchCheck extends SquidCheck<LexerlessGrammar> {

  private static final int MINIMUM_CASE = 3;

  @Override
  public void init() {
    subscribeTo(FlexGrammar.SWITCH_STATEMENT);
  }

  @Override
  public void visitNode(AstNode astNode) {
    int nbCase = 0;
    for (AstNode caseElement : astNode.getChildren(FlexGrammar.CASE_ELEMENT)) {
      nbCase += caseElement.getChildren(FlexGrammar.CASE_LABEL).size();
    }

    if (nbCase < MINIMUM_CASE) {
      getContext().createLineViolation(this, "Replace this \"switch\" statement with \"if\" statements to increase readability.", astNode);
    }
  }

}

==> flex-checks-2.4.0.1222-sources.jar: org/sonar/flex/checks/NotEnoughCaseForSwitchCheck.java <==
/*
 * SonarQube Flex Plugin
 * Copyright (C) 2010-2018 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.flex.checks;

import com.sonar.sslr.api.AstNode;
import com.sonar.sslr.api.AstNodeType;
import java.util.Collections;
import java.util.List;
import org.sonar.check.Rule;
import org.sonar.flex.FlexCheck;
import org.sonar.flex.FlexGrammar;

@Rule(key = "S1301")
public class NotEnoughCaseForSwitchCheck extends FlexCheck {

  private static final int MINIMUM_CASE = 3;

  @Override
  public List<AstNodeType> subscribedTo() {
    return Collections.singletonList(FlexGrammar.SWITCH_STATEMENT);
  }

  @Override
  public void visitNode(AstNode astNode) {
    int nbCase = 0;
    for (AstNode caseElement : astNode.getChildren(FlexGrammar.CASE_ELEMENT)) {
      nbCase += caseElement.getChildren(FlexGrammar.CASE_LABEL).size();
    }

    if (nbCase < MINIMUM_CASE) {
      addIssue("Replace this \"switch\" statement with \"if\" statements to increase readability.", astNode);
    }
  }

}
